use std::marker::PhantomData;

use organic::types::Citation;
use serde::Deserialize;
use serde::Serialize;

use super::macros::to_wasm;
use super::standard_properties::WasmStandardProperties;
use super::to_wasm::ToWasm;
use crate::wasm::to_wasm::ToWasmStandardProperties;

#[derive(Debug, Serialize, Deserialize)]
#[serde(tag = "ast_node")]
#[serde(rename = "org-data")]
pub(crate) struct WasmCitation<'s> {
    standard_properties: WasmStandardProperties,
    children: Vec<()>,
    phantom: PhantomData<&'s ()>,
}

to_wasm!(
    WasmCitation<'s>,
    Citation<'s>,
    wasm_context,
    standard_properties,
    {
        Ok(WasmCitation {
            standard_properties,
            children: Vec::new(),
            phantom: PhantomData,
        })
    }
);
