use std::marker::PhantomData;

use organic::types::CommentBlock;
use serde::Deserialize;
use serde::Serialize;

use super::macros::to_wasm;
use super::standard_properties::WasmStandardProperties;
use super::to_wasm::ToWasm;
use crate::wasm::to_wasm::ToWasmStandardProperties;

#[derive(Debug, Serialize, Deserialize)]
#[serde(tag = "ast_node")]
#[serde(rename = "org-data")]
pub(crate) struct WasmCommentBlock<'s> {
    standard_properties: WasmStandardProperties,
    children: Vec<()>,
    phantom: PhantomData<&'s ()>,
}

to_wasm!(
    WasmCommentBlock<'s>,
    CommentBlock<'s>,
    wasm_context,
    standard_properties,
    {
        Ok(WasmCommentBlock {
            standard_properties,
            children: Vec::new(),
            phantom: PhantomData,
        })
    }
);
